@@ -1,8 +1,11 @@
 package Chart::Clicker::Shape;
 use strict;
+use warnings;
 
 use base 'Class::Accessor';
-__PACKAGE__->mk_accessors(qw());
+
+1;
+__END__
 
 =head1 NAME
 
@@ -40,5 +43,7 @@ Cory 'G' Watson <gphat@cpan.org>
 
 perl(1)
 
-=cut
-1;
+=head1 LICENSE
+
+You can redistribute and/or modify this code under the same terms as Perl
+itself.
